==> mule-netty-http-service-0.2.12-20251107.160354-12-sources.jar: org/mule/service/http/netty/impl/util/HttpLoggingHandler.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 */
package org.mule.service.http.netty.impl.util;

import static java.nio.charset.Charset.defaultCharset;

import static io.netty.handler.logging.LogLevel.DEBUG;
import static reactor.netty.transport.logging.AdvancedByteBufFormat.TEXTUAL;

import java.net.SocketAddress;

import io.netty.channel.ChannelDuplexHandler;
import io.netty.channel.ChannelHandler.Sharable;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelPromise;
import io.netty.handler.logging.LoggingHandler;

/**
 * Handler to print "Wire Logging". This is only considering read, write, flush, connect, and close events. This handler delegates
 * the format to {@link reactor.netty.transport.logging.AdvancedByteBufFormat#TEXTUAL}.
 */
@Sharable
public class HttpLoggingHandler extends ChannelDuplexHandler {

  private static final String LEGACY_WIRE_LOGGER_NAME = "org.mule.service.http.impl.service.HttpMessageLogger";
  private final LoggingHandler delegate;

  public static HttpLoggingHandler textual(String identifier) {
    return new HttpLoggingHandler(TEXTUAL.toLoggingHandler(LEGACY_WIRE_LOGGER_NAME + "." + identifier, DEBUG, defaultCharset()));
  }

  private HttpLoggingHandler(LoggingHandler delegate) {
    this.delegate = delegate;
  }

  @Override
  public void channelRead(ChannelHandlerContext ctx, Object msg) throws Exception {
    delegate.channelRead(ctx, msg);
  }

  @Override
  public void write(ChannelHandlerContext ctx, Object msg, ChannelPromise promise) throws Exception {
    delegate.write(ctx, msg, promise);
  }

  @Override
  public void flush(ChannelHandlerContext ctx) throws Exception {
    delegate.flush(ctx);
  }

  @Override
  public void connect(ChannelHandlerContext ctx, SocketAddress remoteAddress, SocketAddress localAddress, ChannelPromise promise)
      throws Exception {
    delegate.connect(ctx, remoteAddress, localAddress, promise);
  }

  @Override
  public void close(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
    delegate.close(ctx, promise);
  }

  @Override
  public void channelReadComplete(ChannelHandlerContext ctx) throws Exception {
    delegate.channelReadComplete(ctx);
  }

  @Override
  public void channelInactive(ChannelHandlerContext ctx) throws Exception {
    delegate.channelInactive(ctx);
  }

  @Override
  public void handlerRemoved(ChannelHandlerContext ctx) throws Exception {
    delegate.handlerRemoved(ctx);
  }

  @Override
  public void channelActive(ChannelHandlerContext ctx) throws Exception {
    delegate.channelActive(ctx);
  }

  @Override
  public void handlerAdded(ChannelHandlerContext ctx) throws Exception {
    delegate.handlerAdded(ctx);
  }

  @Override
  public void bind(ChannelHandlerContext ctx, SocketAddress localAddress, ChannelPromise promise) throws Exception {
    delegate.bind(ctx, localAddress, promise);
  }

  @Override
  public void disconnect(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
    delegate.disconnect(ctx, promise);
  }

  @Override
  public void deregister(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
    delegate.deregister(ctx, promise);
  }

  @Override
  public void userEventTriggered(ChannelHandlerContext ctx, Object evt) throws Exception {
    delegate.userEventTriggered(ctx, evt);
  }
}

==> mule-netty-http-service-0.3.0-20250826.221424-478-sources.jar: org/mule/service/http/netty/impl/util/HttpLoggingHandler.java <==
/*
 * Copyright 2023 Salesforce, Inc. All rights reserved.
 */
package org.mule.service.http.netty.impl.util;

import static java.nio.charset.Charset.defaultCharset;

import static io.netty.handler.logging.LogLevel.DEBUG;
import static reactor.netty.transport.logging.AdvancedByteBufFormat.HEX_DUMP;
import static reactor.netty.transport.logging.AdvancedByteBufFormat.TEXTUAL;

import java.net.SocketAddress;

import io.netty.channel.ChannelDuplexHandler;
import io.netty.channel.ChannelHandler.Sharable;
import io.netty.channel.ChannelHandlerContext;
import io.netty.channel.ChannelPromise;
import io.netty.handler.logging.LoggingHandler;

/**
 * Handler to print "Wire Logging". This is only considering read, write, flush, connect, and close events. This handler delegates
 * the format to {@link reactor.netty.transport.logging.AdvancedByteBufFormat#TEXTUAL}.
 */
@Sharable
public class HttpLoggingHandler extends ChannelDuplexHandler {

  private static final String LEGACY_WIRE_LOGGER_NAME = "org.mule.service.http.impl.service.HttpMessageLogger";
  private final LoggingHandler delegate;

  public static HttpLoggingHandler hexDump() {
    return new HttpLoggingHandler(HEX_DUMP.toLoggingHandler(LEGACY_WIRE_LOGGER_NAME, DEBUG, defaultCharset()));
  }

  public static HttpLoggingHandler textual() {
    return new HttpLoggingHandler(TEXTUAL.toLoggingHandler(LEGACY_WIRE_LOGGER_NAME, DEBUG, defaultCharset()));
  }

  private HttpLoggingHandler(LoggingHandler delegate) {
    this.delegate = delegate;
  }

  @Override
  public void channelRead(ChannelHandlerContext ctx, Object msg) throws Exception {
    delegate.channelRead(ctx, msg);
  }

  @Override
  public void write(ChannelHandlerContext ctx, Object msg, ChannelPromise promise) throws Exception {
    delegate.write(ctx, msg, promise);
  }

  @Override
  public void flush(ChannelHandlerContext ctx) throws Exception {
    delegate.flush(ctx);
  }

  @Override
  public void connect(ChannelHandlerContext ctx, SocketAddress remoteAddress, SocketAddress localAddress, ChannelPromise promise)
      throws Exception {
    delegate.connect(ctx, remoteAddress, localAddress, promise);
  }

  @Override
  public void close(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
    delegate.close(ctx, promise);
  }

  @Override
  public void channelReadComplete(ChannelHandlerContext ctx) throws Exception {
    delegate.channelReadComplete(ctx);
  }

  @Override
  public void channelInactive(ChannelHandlerContext ctx) throws Exception {
    delegate.channelInactive(ctx);
  }

  @Override
  public void handlerRemoved(ChannelHandlerContext ctx) throws Exception {
    delegate.handlerRemoved(ctx);
  }

  @Override
  public void channelActive(ChannelHandlerContext ctx) throws Exception {
    delegate.channelActive(ctx);
  }

  @Override
  public void handlerAdded(ChannelHandlerContext ctx) throws Exception {
    delegate.handlerAdded(ctx);
  }

  @Override
  public void bind(ChannelHandlerContext ctx, SocketAddress localAddress, ChannelPromise promise) throws Exception {
    delegate.bind(ctx, localAddress, promise);
  }

  @Override
  public void disconnect(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
    delegate.disconnect(ctx, promise);
  }

  @Override
  public void deregister(ChannelHandlerContext ctx, ChannelPromise promise) throws Exception {
    delegate.deregister(ctx, promise);
  }

  @Override
  public void userEventTriggered(ChannelHandlerContext ctx, Object evt) throws Exception {
    delegate.userEventTriggered(ctx, evt);
  }
}
